#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_IROUND_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_IROUND_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/scalar/iround.hpp>

#endif
